==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/server/webmail.php <==
<?php
/* @brief : Main server side application file
 * @author Pavel Perna
 * @date 17-04-2007  
 */

// include libs
require_once('inc/include.php');
require_once('inc/user.php');
require_once('inc/xmlrequest.php');

/* @name: Answering function
 * @brief:This function echoes an answer 
 * for client side request to server
 */  
function answer($result,$contentType = 'text/xml')
{
	//$length = strlen($result);
	header('Content-Type: ' . $contentType);

  //GZIP
   if (!ini_get("output_handler"))    
    ob_start("ob_gzhandler");
	
	echo $result;  
}

/* @name: Main application function
 * @brief:This function is processed each time 
 * client side request's an action from server
 */  
function main()
{

	if (DEBUG) echo "WARNING : DEBUGGING MODE SELECTED(to switch off, set DEBUG constant to 0 in inc/include.php\r\n";

  
	
	$sSTime = time();
	
	try{
    // handle request
    
		$cXMLRequest = &new XMLRequest();
		$answer = &$cXMLRequest->answer();
		switch ($cXMLRequest->sFormatType) {
		case 'xml':
			$contentType = 'text/xml';
			$result = &$answer;
			break;
		
		case 'json':
			$contentType = 'text/json';
			$result = Tools::str2JSArray($answer);

      break;
			
		default:
			throw new Exc('unknown result format requested','unkown_format');
		}
		
		log_buffer($answer, 'RESPONSE');
		
	//handle errors
	}catch(Exc $e){
		//DEBUG : remove ( traces exception $e )  
		if (DEBUG)
			print_r($e);

		//XML Answer to the browser
		$result = $e->XMLResponse();
		$contentType = 'text/xml';
		log_buffer($result, 'ERROR');
	}
  answer($result,	$contentType);
}

//Run application
main();


?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/server/webmail.php <==
<?php
/* @brief : Main server side application file
 * @author Pavel Perna
 * @date 17-04-2007  
 */

// include libs
require_once('inc/include.php');
require_once('inc/user.php');
require_once('inc/xmlrequest.php');

/* @name: Answering function
 * @brief:This function echoes an answer 
 * for client side request to server
 */  
function answer($result,$contentType = 'text/xml')
{
	//$length = strlen($result);
	header('Content-Type: ' . $contentType);

  //GZIP
   if (!ini_get("output_handler"))    
    ob_start("ob_gzhandler");
	
	echo $result;  
}

/* @name: Main application function
 * @brief:This function is processed each time 
 * client side request's an action from server
 */  
function main()
{
	
	$sSTime = time();
	
	try{
    // handle request
    
		$cXMLRequest = &new XMLRequest();
		$answer = &$cXMLRequest->answer();
		switch ($cXMLRequest->sFormatType) {
		case 'xml':
			$contentType = 'text/xml';
			$result = &$answer;
			break;
		
		case 'json':
			$contentType = 'text/json';
			$result = Tools::str2JSArray($answer);

      break;
			
		default:
			throw new Exc('xmlrequest_unkown_format',$cXMLRequest->sFormatType);
		}
		
		log_buffer($answer, 'RESPONSE');
		
	//handle errors
	}catch(Exc $e){
		//DEBUG : remove ( traces exception $e )  
		log_buffer("EXCEPTION: ".$e->Message(),'DEBUG');
		//XML Answer to the browser
		$result = $e->XMLResponse();
		$contentType = 'text/xml';
		log_buffer($result, 'ERROR');
	}

  answer($result,	$contentType);
}

//Run application
main();


?>
